Module html

Module html 

Constants

DEFAULT_DESC_LENGTH

Functions

html_to_text
Filters a DOM tree into a text document used for indexing
process_canonical_url
Processes the html document and pulls out the canonical url